import Module from '@/components/modules/module'
import Setting from '@/setting'
import Util from '@/libs/util'
import { Loading } from 'element-ui'
export default {
  data() {
    return {
      userId: +this.$store.state.user.userId,
      site: this.$store.state.content.site,
      columnId: +this.$route.query.id,
      withOriginForm: ['introduce', 'history'], // 要添加origiinForm的模块类型
      id: '',
      modules: [],
      originModules: '[]',
      diaVisible: false,
      curModule: 0,
      curListIndex: 0,
      curData: {},
      pass: false,
    }
  },
  components: {
    Module,
  },
  // 页面离开的时候如果没有保存则提示
  beforeRouteLeave(to, from, next) {
    // 更改了信息才需要提示
    if (!this.pass && this.modules.length && this.originModules !== JSON.stringify(this.modules)) {
      this.$confirm(`所填写内容暂未保存，是否保存？`, '提示', {
        type: 'warning'
      }).then(() => {
        this.save(1, 1)
        next()
      }).catch(() => {
        next()
      })
    } else {
      next()
    }
  },
  mounted() {
    this.getInfo()
  },
  methods: {
    // 获取详情
    getInfo() {
      const siteId = this.$store.state.content.site.id
      this.modules.map(e => {
        const { type, list, form } = e
        // 克隆一个原始row，方便添加
        if (this.withOriginForm.includes(type)) {
          const data = JSON.parse(JSON.stringify(e.form || e.list[0]))
          for (const i in data) {
            if (typeof data[i] === 'string') data[i] = ''
          }
          e.originForm = data
        }
        // 站点id默认设置为当前站点
        e.list && e.list.map(e => {
          if (e.link && !e.link.site) e.link.site = siteId
          if (type === 'columns' && !e.site) e.site = siteId
        })
        if (form && form.link && !form.link.site) form.link.site = siteId
        if (form && type === 'column' && !form.site) form.site = siteId
      })
      const { modules } = this
      // 查询页面详情
      this.$post(`${this.api.findPage}?columnId=${this.columnId}`).then(({ data }) => {
        if (data.length) {
          const json = data[0]
          this.id = json.id
          const str = json[json.state ? 'theEditedJson' : 'jsonBeforeEditing']
          const list = JSON.parse(str)

          this.modules.map((e, i) => {
						e.form = list[i].form
						if (list[i].list) e.list = list[i].list
            if (this.withOriginForm.includes(e.type) && !e.originForm) {
              e.originForm = modules[i].originForm
            }
          })
          this.originModules = JSON.stringify(this.modules) // 原始json，用以页面离开的时候判断是否需要提示保存
          console.log("🚀 ~ file: index.js:85 ~ this.$post ~ list:", this.modules)
        }
      }).catch(err => {})
    },
    // 展开模块设置
    toSet(i, listIndex) {
      this.curModule = i
      this.curData = JSON.parse(JSON.stringify(this.modules[i]))

      const { type } = this.curData
      if (type === 'columns' || type === 'forms') {
        this.curListIndex = listIndex
        this.curData.form = JSON.parse(JSON.stringify(this.curData.list[listIndex]))
      }
      this.diaVisible = true
    },
    // 模块设置提交
    moduleSubmited() {
      this.diaVisible = false
      const { type } = this.curData
      if (type === 'columns' || type === 'forms') {
        const { form } = this.curData
        if (type === 'columns') form.columnName = form[form.columnTitle === 2 ? 'columnTitleCustom' : 'columnName']
        this.modules[this.curModule].list[this.curListIndex] = JSON.parse(JSON.stringify(form))
      } else {
        this.modules[this.curModule] = this.curData
      }
    },
    // 模块设置提交验证
    moduleSubmit() {
      const formEle = this.$refs.module.$refs.form
      // 有表单的要验证必填，没有的直接关闭弹框
      if (formEle) {
        formEle.validate((valid) => {
          valid && this.moduleSubmited()
        })
      } else {
        this.moduleSubmited()
      }
    },
    // 处理预览和保存的json
    handleJson() {
      return JSON.stringify(this.modules)
    },
    // 预览
    preview() {
      const load = Loading.service()
      this.$post(this.api.saveRedisPage, {
        columnId: this.columnId,
        json: this.handleJson()
      }).then(res => {
        load.close()
        window.open((Setting.isDev ? `http://${location.hostname}:8095` : this.$store.state.content.site.domainName) + `/#/${this.$route.query.path}?id=${this.columnId}&preview=1&siteId=${this.$route.query.siteId}`)
      }).catch(err => {
        load.close()
      })
    },
    // 保存
    save(state, leave) {
      const json = this.handleJson()
      const data = {
        id: this.id,
        columnId: this.columnId,
        state,
        sort: 1,
        founderId: this.userId,
        editorId: this.userId,
        jsonBeforeEditing: json
      }
      if (state) data.theEditedJson = json
      this.$post(this.api[this.id ? 'updatePage' : 'savePage'], data).then(res => {
        this.originModules = json
        Util.successMsg((state ? '发布' : '保存') +  '成功')
        leave || this.$router.back()
      }).catch(err => {})
    },
    // 返回
    back() {
      this.pass = true
      // 更改了信息才需要提示
      if (this.originModules !== JSON.stringify(this.modules)) {
        this.$confirm(`所填写内容暂未保存，是否保存？`, '提示', {
          type: 'warning'
        }).then(() => {
          this.save(1)
        }).catch(() => {
          this.$router.back()
        })
      } else {
        this.$router.back()
      }
    },
  }
};