import axios from 'axios'
import Util from '@/libs/util'
import Setting from '@/setting'
import store from '@/store'

const service = axios.create({
  baseURL: Setting.apiBaseURL,
  timeout: 1000 * 60 * 60 * 6
});
// post请求头
service.defaults.headers.post['Content-Type'] = 'application/json;charset=UTF-8'
service.defaults.headers['X-Content-Type-Options'] = 'nosniff'
service.defaults.headers['Content-Security-Policy'] = 'script-src "self"; object-src "none";style-src cdn.example.org third-party.org; child-src https:'
// 请求拦截器
service.interceptors.request.use(config => {
  let token = Util.local.get(Setting.tokenKey);
  if (token) config.headers.token = token
  return config;
}, err => {
  Util.errorMsg({
      message: "退出登陆",
      onClose: function() {
          store.dispatch('user/logout')
      }
  });
  return Promise.reject(err);
});

// 响应拦截器
service.interceptors.response.use(
  response => {
    const res = response.data
    const { status, code } = res
    if (status === 200) {
      return Promise.resolve(res).catch(e => {});
    } else if (code === '200') {
      return Promise.resolve(res).catch(e => {});
    } else if (status === 401) {
      Util.errorMsg(res.message)
      setTimeout(() => {
        store.dispatch('user/logout')
      }, 1000)
      return Promise.reject(res)
    } else {
      Util.errorMsg(res.message);
      return Promise.reject(res)
    }
  },
  // 服务器状态码不是200的情况
  error => {
		const { status, data } = error.response
      if (status) {
          const { message } = data
          switch (status) {
              // 401: 未登录
              case 401:
                Util.errorMsg("登录过期，请重新登录");
                setTimeout(() => {
                  store.dispatch('user/logout')
                }, 1000);
                break;
            // 403 token过期
            case 403:
                Util.errorMsg("登录过期，请重新登录");
                setTimeout(() => {
                  store.dispatch('user/logout')
                }, 1000);
                break;
            // 其他错误，直接抛出错误提示
            default:
                Util.errorMsg(message);
                Promise.reject(data);
          }
          return Promise.reject(error.response);
      }
  }
);

function get(url, params) {
  return new Promise((resolve, reject) => {
      service.get(url, { params: params }).then(res => {
          resolve(res);
      }).catch(err => {
          reject(err);
      });
  });
}

function post(url, params) {
  return new Promise((resolve, reject) => {
      service.post(url, params).then(res => {
          resolve(res);
      }).catch(err => {
          reject(err.data);
      });
  });
}

function del(url, params) {
  return new Promise((resolve, reject) => {
      service.delete(url, {
        data: params
      }).then(res => {
          resolve(res);
      }).catch(err => {
          reject(err.data);
      });
  });
}

function put(url, params) {
  return new Promise((resolve, reject) => {
      service.put(url, params).then(res => {
          resolve(res);
      }).catch(err => {
          reject(err.data);
      });
  });
}

export { get, post, del, put };